# REPLference.jl Tasks

To contribute to the `REPLference.jl` package, you can solve tasks listed in the
[`# Todo`](https://github.com/udohjeremiah/REPLference.jl/blob/master/TODO.md#todo)
section of this file. These tasks are specific to the upcoming release. Here are the steps
to follow:

1. If you find an unassigned task in the
   [`# Todo`](https://github.com/udohjeremiah/REPLference.jl/blob/master/TODO.md#todo)
   section, add your username to the task name in the
   [`# In Progress...`](https://github.com/udohjeremiah/REPLference.jl/blob/master/TODO.md#in-progress)
   section. Also, include a link to the branch or repository you're working on and remove
   the task from the [`# Todo`](https://github.com/udohjeremiah/REPLference.jl/blob/master/TODO.md#todo)
   section. This indicates that you're working on it. For example:
   `Tasktitle [branch-name](https://github.com/<repo>) @john`.

2. If someone else is already working on a task that you want to help with, collaborate with
   them by opening a pull request in the branch or repository where the change is being
   made. Request to be added to the pull request. If accepted, the initial contributor who
   started working on the task should update the
   [`# In Progress...`](https://github.com/udohjeremiah/REPLference.jl/blob/master/TODO.md#in-progress)
   section to add your name to the list of usernames. This prevents duplication of effort
   and ensures efficient and effective development. For example:
   `Tasktitle [branch-name](https://github.com/<repo>) @john, @mary`.

3. When you finish a task, open a pull request with the changes. If the package maintainers
   approve and merge the pull request, open another pull request to remove the task from the
   [`# In Progress...`](https://github.com/udohjeremiah/REPLference.jl/blob/master/TODO.md#in-progress)
   and add it to the [`Done ✓`](https://github.com/udohjeremiah/REPLference.jl/blob/master/TODO.md#done-)
   section. In the comment section of the pull request, state the PR number for the merged
   pull request (generated by the hosting service). For example:
   `Remove Tasktitle from In Progress... and add to Done section: #1234`.

4. If a task in the [`# Todo`](https://github.com/udohjeremiah/REPLference.jl/blob/master/TODO.md#todo)
   section is not completed for the upcoming release, it will be carried over to the next
   release by default. However, the package maintainers may decide to remove it from the
   list. Before starting fresh for the next release, ensure that the
   [`Done ✓`](https://github.com/udohjeremiah/REPLference.jl/blob/master/TODO.md#done-)
   section is cleared.

To see what's happening in a section, click on the arrow symbol (▶).

## Todo

<details><summary></summary>

- [ ] Create the `src` directory:
    - [ ] Create a `_23_metaprogramming.jl` file that contains a manual about
          metaprogramming in Julia and the methods that can be called on the topic.
    - [ ] Create a `_24_error.jl` file that contains a manual about error handling in Julia
          and the methods that can be called on the topic.
    - [ ] Create a `_25_pointer.jl` file that contains a manual about pointers in Julia and
          the methods that can be called on them.
    - [ ] Create a `_26_system.jl` file that contains a manual about systems in Julia and
          the methods that can be called on the topic.
    - [ ] Create a `_27_thread.jl` file that contains a manual about threads in Julia and
          the methods that can be called on the topic.
</details>

## In Progress...

<details><summary></summary>

- [ ] Register the package and/or release this version.
</details>

## Done ✓

<details><summary></summary>

- [x] Create the `LICENCE.md` file: [`#6`](https://github.com/udohjeremiah/REPLference.jl/pull/6)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `CITATION.bib` file: [`#9`](https://github.com/udohjeremiah/REPLference.jl/pull/9)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `utility_script.jl` file: [`#13`](https://github.com/udohjeremiah/REPLference.jl/pull/13)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Provide test for the names in `utility_script.jl`: [`#16`](https://github.com/udohjeremiah/REPLference.jl/pull/16)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Generate the `all_names.txt` file: [`19`](https://github.com/udohjeremiah/REPLference.jl/pull/19)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `Project.toml` file: [`#21`](https://github.com/udohjeremiah/REPLference.jl/pull/21)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_2_variable.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_3_operator.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_4_integer.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_5_float.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_6_complex.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_7_rational.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_8_irrational.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_9_character.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_10_string.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_11_range.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_12_array.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_13_tuple.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_14_dict.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_15_set.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_16_type.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_17_function.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_18_file.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_19_module.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_20_regex.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_21_date.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `_22_radom.jl` file: [`#28`](https://github.com/udohjeremiah/REPLference.jl/pull/28)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Add `AbstractTrees.jl` as dependency and create internal functions to display subtypes
      and supertypes: [`#31`](https://github.com/udohjeremiah/REPLference.jl/pull/31)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Add the `man`,`fun`, and `tree` functions to the `REPLference.jl` file:
      [`#34`](https://github.com/udohjeremiah/REPLference.jl/pull/34)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Provide test for the names in `REPLference.jl`: [`#37`](https://github.com/udohjeremiah/REPLference.jl/pull/37)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `.gitignore` file: [`#40`](https://github.com/udohjeremiah/REPLference.jl/pull/40)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Create the `./github/workflows` file: [`#44`](https://github.com/udohjeremiah/REPLference.jl/pull/44)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Add badges to the `README.md` file: [`#46`](https://github.com/udohjeremiah/REPLference.jl/pull/46)
      [@udohjeremiah](https://github.com/udohjeremiah)
- [x] Add necessary information about the package in the `README.md` file: [`#50`](https://github.com/udohjeremiah/REPLference.jl/pull/50)
      [@udohjeremiah](https://github.com/udohjeremiah)
</details>
